pub struct InvocationId(/* private fields */);Expand description
Uniquely identifies a single invocation instance (UUID).
Each time a call is routed for execution, a new invocation is created. Multiple invocations can exist for the same call (retries, concurrent runs).
Implementations
Sourceimpl InvocationId
impl InvocationId